@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"net"
 	"net/http"
+	"strings"
 	"time"
 
 	"github.com/autobrr/autobrr/internal/config"
@@ -26,13 +27,11 @@ type Server struct {
 	sse *sse.Server
 	db  DatabaseHealth
 
+	buildInfo      buildInfo
 	config         *config.AppConfig
+	allowedOrigins []string
 	sessionManager *scs.SessionManager
 
-	version string
-	commit  string
-	date    string
-
 	actionService         actionService
 	apiService            apikeyService
 	authService           authService
@@ -75,24 +74,29 @@ type Deps struct {
 	UpdateService         updateService
 }
 
-func NewServer(deps Deps) Server {
-	//sessionManager := scs.New()
+func NewServer(deps Deps) *Server {
 	sessionManager := deps.SessionManager
 	sessionManager.Lifetime = 24 * time.Hour * 30
-	//sessionManager.Lifetime = 1 * time.Minute
-
-	//sessionManager.IdleTimeout = 20 * time.Minute
 	sessionManager.Cookie.Name = "autobrr_user_session"
 	sessionManager.Cookie.Persist = false
 
-	srv := Server{
-		log:     deps.Log.With().Str("module", "http").Logger(),
-		config:  deps.Config,
-		sse:     deps.SSE,
-		db:      deps.DB,
-		version: deps.Version,
-		commit:  deps.Commit,
-		date:    deps.Date,
+	srv := &Server{
+		log:    deps.Log.With().Str("module", "http").Logger(),
+		config: deps.Config,
+		allowedOrigins: []string{
+			"*",
+			//"http://localhost:3000",
+			//"http://localhost:7474",
+			//"http://127.0.0.1:3000",
+			//"http://127.0.0.1:7474",
+		},
+		sse: deps.SSE,
+		db:  deps.DB,
+		buildInfo: buildInfo{
+			version: deps.Version,
+			commit:  deps.Commit,
+			date:    deps.Date,
+		},
 
 		sessionManager: sessionManager,
 
@@ -111,10 +115,14 @@ func NewServer(deps Deps) Server {
 		updateService:         deps.UpdateService,
 	}
 
+	if deps.Config.Config.CorsAllowedOrigins != "*" {
+		srv.allowedOrigins = strings.Split(deps.Config.Config.CorsAllowedOrigins, ",")
+	}
+
 	return srv
 }
 
-func (s Server) Open() error {
+func (s *Server) Open() error {
 	addr := fmt.Sprintf("%v:%v", s.config.Config.Host, s.config.Config.Port)
 
 	var err error
@@ -129,7 +137,7 @@ func (s Server) Open() error {
 	return err
 }
 
-func (s Server) tryToServe(addr, protocol string) error {
+func (s *Server) tryToServe(addr, protocol string) error {
 	listener, err := net.Listen(protocol, addr)
 	if err != nil {
 		return err
@@ -145,7 +153,7 @@ func (s Server) tryToServe(addr, protocol string) error {
 	return server.Serve(listener)
 }
 
-func (s Server) Handler() http.Handler {
+func (s *Server) Handler() http.Handler {
 	r := chi.NewRouter()
 
 	r.Use(middleware.RequestID)
@@ -155,8 +163,9 @@ func (s Server) Handler() http.Handler {
 
 	c := cors.New(cors.Options{
 		AllowCredentials:   true,
-		AllowedMethods:     []string{"HEAD", "OPTIONS", "GET", "POST", "PUT", "PATCH", "DELETE"},
-		AllowOriginFunc:    func(origin string) bool { return true },
+		AllowedMethods:     []string{http.MethodHead, http.MethodOptions, http.MethodGet, http.MethodPost, http.MethodPut, http.MethodPatch, http.MethodDelete},
+		AllowedHeaders:     []string{"Authorization"},
+		AllowedOrigins:     s.allowedOrigins,
 		OptionsPassthrough: true,
 		// Enable Debugging for testing, consider disabling in production
 		Debug: false,
@@ -176,7 +185,7 @@ func (s Server) Handler() http.Handler {
 			r.Use(s.IsAuthenticated)
 
 			r.Route("/actions", newActionHandler(encoder, s.actionService).Routes)
-			r.Route("/config", newConfigHandler(encoder, s, s.config).Routes)
+			r.Route("/config", newConfigHandler(encoder, s.buildInfo, s.config).Routes)
 			r.Route("/download_clients", newDownloadClientHandler(encoder, s.downloadClientService).Routes)
 			r.Route("/filters", newFilterHandler(encoder, s.filterService).Routes)
 			r.Route("/feeds", newFeedHandler(encoder, s.feedService).Routes)
@@ -215,13 +224,13 @@ func (s Server) Handler() http.Handler {
 		// this is required to keep assets "url rewritable" via a reverse-proxy
 		routeAssetBaseURL := "./"
 		// serve the web
-		webHandlers := newWebLegacyHandler(s.log, web.DistDirFS, s.version, s.config.Config.BaseURL, routeAssetBaseURL)
+		webHandlers := newWebLegacyHandler(s.log, web.DistDirFS, s.buildInfo.version, s.config.Config.BaseURL, routeAssetBaseURL)
 		webHandlers.RegisterRoutes(webRouter)
 	} else {
 		routeBaseURL = s.config.Config.BaseURL
 
 		// serve the web
-		webHandlers := newWebHandler(s.log, web.DistDirFS, s.version, routeBaseURL, routeBaseURL)
+		webHandlers := newWebHandler(s.log, web.DistDirFS, s.buildInfo.version, routeBaseURL, routeBaseURL)
 		webHandlers.RegisterRoutes(webRouter)
 
 		// add fallback routes when base url is set to inform user to redirect and use /baseurl/
