@@ -10,6 +10,7 @@ import (
 	"strings"
 
 	"github.com/autobrr/autobrr/internal/domain"
+	"github.com/autobrr/autobrr/pkg/sharedhttp"
 
 	"github.com/pkg/errors"
 )
@@ -42,7 +43,7 @@ func (s *service) trakt(ctx context.Context, list *domain.List) error {
 	if err != nil {
 		return errors.Wrapf(err, "failed to fetch titles from URL: %s", list.URL)
 	}
-	defer resp.Body.Close()
+	defer sharedhttp.DrainAndClose(resp)
 
 	if resp.StatusCode != http.StatusOK {
 		return errors.Errorf("failed to fetch titles from URL: %s", list.URL)
