@@ -4,18 +4,16 @@ package scheduler
 
 import (
 	"os"
-	"os/user"
 	"strconv"
 	"syscall"
 )
 
 // isOwnedByCurrentUser checks if a file is owned by the current user on Unix systems
-func isOwnedByCurrentUser(currentUser *user.User, fileInfo os.FileInfo) bool {
+func isOwnedByCurrentUser(userID string, fileInfo os.FileInfo) bool {
 	if stat, ok := fileInfo.Sys().(*syscall.Stat_t); ok {
 		fileUID := stat.Uid
-		currentUID := currentUser.Uid
 
-		if uidInt, err := strconv.ParseUint(currentUID, 10, 32); err == nil {
+		if uidInt, err := strconv.ParseUint(userID, 10, 32); err == nil {
 			return uint32(uidInt) == fileUID
 		}
 	}
