@@ -4,6 +4,8 @@ import (
 	"strings"
 
 	g "github.com/anacrolix/generics"
+
+	infohash_v2 "github.com/anacrolix/torrent/types/infohash-v2"
 )
 
 // Information specific to a single file inside the MetaInfo structure.
@@ -14,14 +16,14 @@ type FileInfo struct {
 	Path   []string `bencode:"path"` // BEP3
 	// Unofficial extension by BiglyBT? https://github.com/BiglySoftware/BiglyBT/issues/1274. Might
 	// be a safer bet when available: https://github.com/anacrolix/torrent/pull/915.
-	PathUtf8 []string `bencode:"path.utf-8,omitempty"`
+	PathUtf8 []string `bencode:"path.utf-8,omitempty" json:"path.utf-8,omitempty"`
 
-	ExtendedFileAttrs
+	ExtendedFileAttrs `json:",omitempty"`
 
 	// BEP 52. This isn't encoded in a v1 FileInfo, but is exposed here for APIs that expect to deal
 	// v1 files.
-	PiecesRoot    g.Option[[32]byte] `bencode:"-"`
-	TorrentOffset int64              `bencode:"-"`
+	PiecesRoot    g.Option[infohash_v2.T] `bencode:"-" json:"-"`
+	TorrentOffset int64                   `bencode:"-" json:"-"`
 }
 
 func (fi *FileInfo) DisplayPath(info *Info) string {
@@ -38,3 +40,17 @@ func (fi *FileInfo) BestPath() []string {
 	}
 	return fi.Path
 }
+
+func (fi *FileInfo) BeginPieceIndex(pieceLength int64) int {
+	if pieceLength == 0 {
+		return 0
+	}
+	return int(fi.TorrentOffset / pieceLength)
+}
+
+func (fi *FileInfo) EndPieceIndex(pieceLength int64) int {
+	if pieceLength == 0 {
+		return 0
+	}
+	return int((fi.TorrentOffset + fi.Length + pieceLength - 1) / pieceLength)
+}
